Package: vars
Type: Package
Title: VAR Modelling
Version: 1.6-1
Date: 2024-03-20
Authors@R: c(person("Bernhard", "Pfaff", email = "bernhard@pfaffikus.de", role = c("aut", "cre")), person("Matthieu", "Stigler", role = "ctb"))
Depends: R (>= 2.0.0), MASS, strucchange, urca (>= 1.1-6), lmtest (>=
        0.9-26), sandwich (>= 2.2-4)
Imports: methods
LazyLoad: yes
Description: Estimation, lag selection, diagnostic testing, forecasting, causality analysis, forecast error variance decomposition and impulse response functions of VAR models and estimation of SVAR and SVEC models.
License: GPL (>= 2)
URL: https://www.pfaffikus.de
Author: Bernhard Pfaff [aut, cre],
  Matthieu Stigler [ctb]
Maintainer: Bernhard Pfaff <bernhard@pfaffikus.de>
LazyData: true
Repository: CRAN
Repository/R-Forge/Project: vars
Repository/R-Forge/Revision: 99
Repository/R-Forge/DateTimeStamp: 2013-07-21 14:35:42
Date/Publication: 2024-03-21 12:20:02 UTC
Packaged: 2024-03-20 21:22:36 UTC; bp
NeedsCompilation: no
Built: R 4.4.1; ; 2024-06-27 23:33:15 UTC; unix
